==> nextcloud-32.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/lt_LT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informacija apie procesorių neprieinama",
    "CPU Usage:" : "CPU naudojimas:",
    "RAM Usage:" : "RAM naudojimas:",
    "SWAP Usage:" : "SWAP naudojimas:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Iš viso: {memTotalBytes}/Naudojama: {memUsageBytes}",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
    "System" : "Sistema",
    "Monitoring" : "Stebėjimas",
    "Monitoring app with useful server information" : "Stebėjimo programėlė su naudinga serverio informacija",
    "Operating System:" : "Operacinė sistema:",
    "CPU:" : "Procesorius:",
    "Memory:" : "Atmintis:",
    "Server time:" : "Serverio laikas:",
    "Temperature" : "Temperatūra",
    "Load" : "Apkrova",
    "Memory" : "Atmintis",
    "Disk" : "Diskas",
    "Filesystem:" : "Failų sistema:",
    "Size:" : "Dydis:",
    "Available:" : "Prieinama:",
    "Used:" : "Panaudota:",
    "Files:" : "Failai:",
    "Storages:" : "Saugyklos:",
    "Free Space:" : "Laisva vieta:",
    "Network" : "Tinklas",
    "Gateway:" : "Tinklų sietuvas:",
    "Status:" : "Būsena:",
    "Speed:" : "Greitis:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktyvūs naudotojai",
    "Last hour" : "Paskutinė valanda",
    "Last 24 Hours" : "Paskutinės 24 valandos",
    "Last 7 Days" : "Paskutinės 7 dienos",
    "Last 30 Days" : "Paskutinės 30 dienų",
    "Shares" : "Viešiniai",
    "Users:" : "Naudotojai:",
    "Groups:" : "Grupės:",
    "Links:" : "Nuorodos:",
    "Emails:" : "El. pašto adresai:",
    "PHP" : "PHP",
    "Version:" : "Versija:",
    "Memory limit:" : "Atminties limitas:",
    "Max execution time:" : "Maksimalus vykdymo laikas:",
    "Upload max size:" : "Maksimalus įkeliamo failo dydis:",
    "Extensions:" : "Priedai:",
    "Show phpinfo" : "Rodyti phpinfo",
    "Database" : "Duomenų bazė",
    "Type:" : "Tipas:",
    "External monitoring tool" : "Išorinis stebėjimo įrankis",
    "Copy" : "Kopijuoti",
    "Output in JSON" : "JSON išvedimas",
    "Skip server update" : "Praleisti serverio atnaujinimą",
    "Unknown Processor" : "Nežinomas procesorius"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/serverinfo/l10n/lt_LT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informacija apie procesorių neprieinama",
    "CPU Usage:" : "CPU naudojimas:",
    "Load average: {percentage} % ({load}) last minute" : "Apkrovos vidurkis: {percentage} % ({load}) paskutinę minutę",
    "{lastMinutePercentage} % ({lastMinute}) last Minute\n{last5MinutesPercentage} % ({last5Minutes}) last 5 Minutes\n{last15MinutesPercentage} % ({last15Minutes}) last 15 Minutes" : "{lastMinutePercentage} % ({lastMinute}) paskutinę minutę\n{last5MinutesPercentage} % ({last5Minutes}) paskutines 5 minutes\n{last15MinutesPercentage} % ({last15Minutes}) paskutines 15 minučių",
    "RAM Usage:" : "RAM naudojimas:",
    "SWAP Usage:" : "SWAP naudojimas:",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Iš viso: {memTotalBytes}/Naudojama: {memUsageBytes}",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Press ⌘-C to copy." : "Norėdami nukopijuoti, paspauskite ⌘-C.",
    "Press Ctrl-C to copy." : "Paspauskite Vald-C, norėdami nukopijuoti.",
    "Unknown" : "Nežinoma",
    "%1$d days, %2$d hours, %3$d minutes, %4$d seconds" : "%1$d d., %2$d val., %3$d min., %4$d sek.",
    "%1$d hours, %2$d minutes, %3$d seconds" : "%1$d val., %2$d min., %3$d sek.",
    "System" : "Sistema",
    "Monitoring" : "Stebėjimas",
    "Monitoring app with useful server information" : "Stebėjimo programėlė su naudinga serverio informacija",
    "Operating System:" : "Operacinė sistema:",
    "CPU:" : "Procesorius:",
    "Memory:" : "Atmintis:",
    "Server time:" : "Serverio laikas:",
    "Temperature" : "Temperatūra",
    "Load" : "Apkrova",
    "Memory" : "Atmintis",
    "Disk" : "Diskas",
    "Filesystem:" : "Failų sistema:",
    "Size:" : "Dydis:",
    "Available:" : "Prieinama:",
    "Used:" : "Panaudota:",
    "Files:" : "Failai:",
    "Storages:" : "Saugyklos:",
    "Free Space:" : "Laisva vieta:",
    "Network" : "Tinklas",
    "Gateway:" : "Tinklų sietuvas:",
    "Status:" : "Būsena:",
    "Speed:" : "Greitis:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktyvūs naudotojai",
    "Last hour" : "Paskutinė valanda",
    "Last 24 Hours" : "Paskutinės 24 valandos",
    "Last 7 Days" : "Paskutinės 7 dienos",
    "Last 30 Days" : "Paskutinės 30 dienų",
    "Shares" : "Viešiniai",
    "Users:" : "Naudotojai:",
    "Groups:" : "Grupės:",
    "Links:" : "Nuorodos:",
    "Emails:" : "El. pašto adresai:",
    "PHP" : "PHP",
    "Version:" : "Versija:",
    "Memory limit:" : "Atminties limitas:",
    "Max execution time:" : "Maksimalus vykdymo laikas:",
    "seconds" : "sekundes",
    "Upload max size:" : "Maksimalus įkeliamo failo dydis:",
    "Extensions:" : "Priedai:",
    "Show phpinfo" : "Rodyti phpinfo",
    "Database" : "Duomenų bazė",
    "Type:" : "Tipas:",
    "External monitoring tool" : "Išorinis stebėjimo įrankis",
    "Copy" : "Kopijuoti",
    "Output in JSON" : "JSON išvedimas",
    "Skip server update" : "Praleisti serverio atnaujinimą",
    "Unknown Processor" : "Nežinomas procesorius"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
